# v2.1.0

Initial PyPI release.
 
# v2.0.1

support python 3.10 style optionals (declared as `type | None` instead of `Optional[type]`)

# v2.0.0

transitioned to a decorator instead of a class to inherit from.

# v1.0.2

added `COLCON_IGNORE` file so that the project is ignored in [brains](https://github.com/EPFL-RT-Driverless/brains)
# v1.0.1

fixed bug for numpy array creation


# v1.0.0

initial version
